@@ -4,15 +4,17 @@ from __future__ import absolute_import
 from .capture_api import CaptureApi
 from .conversion_details_api import ConversionDetailsApi
 from .credit_api import CreditApi
-from .flex_token_api import FlexTokenApi
+from .decision_manager_api import DecisionManagerApi
+
+
 from .instrument_identifier_api import InstrumentIdentifierApi
-from .instrument_identifiers_api import InstrumentIdentifiersApi
 from .key_generation_api import KeyGenerationApi
 from .net_fundings_api import NetFundingsApi
 from .notification_of_changes_api import NotificationOfChangesApi
-from .payment_instruments_api import PaymentInstrumentsApi
+from .payment_batch_summaries_api import PaymentBatchSummariesApi
+from .payment_instrument_api import PaymentInstrumentApi
 from .payments_api import PaymentsApi
-from .process_a_payout_api import ProcessAPayoutApi
+from .payouts_api import PayoutsApi
 from .purchase_and_refund_details_api import PurchaseAndRefundDetailsApi
 from .refund_api import RefundApi
 from .report_definitions_api import ReportDefinitionsApi
@@ -22,6 +24,7 @@ from .reports_api import ReportsApi
 from .reversal_api import ReversalApi
 from .search_transactions_api import SearchTransactionsApi
 from .secure_file_share_api import SecureFileShareApi
+from .tokenization_api import TokenizationApi
 from .transaction_batches_api import TransactionBatchesApi
 from .transaction_details_api import TransactionDetailsApi
 from .user_management_api import UserManagementApi
